"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
/**
 * Instances of this class will be used to make authenticated requests to the PUBG API.
 *
 * Instantiate this by providing your API key and the PlatformRegion.
 */
class PubgAPI {
    constructor(apiKey, platformRegion) {
        this._apiKey = apiKey;
        this._platformRegion = platformRegion;
        this._axios = axios_1.default.create({
            baseURL: `https://api.playbattlegrounds.com/shards/${this._platformRegion}/`,
            headers: {
                'Authorization': `Bearer ${this._apiKey}`,
                'Accept': 'application/json',
            },
        });
    }
    /**
     * The AxiosInstance used to make authenticated API requests.
     */
    get axios() {
        return this._axios;
    }
    /**
     * Platform and Region associated with this API instance.
     */
    get platformRegion() {
        return this._platformRegion;
    }
    /**
     * Change the PlatformRegion associated with this API instance.
     */
    set platformRegion(region) {
        this._platformRegion = region;
    }
}
exports.PubgAPI = PubgAPI;
class PubgAPIEndpoint {
    constructor(api) {
        this._api = api;
    }
    get api() {
        return this._api;
    }
}
exports.PubgAPIEndpoint = PubgAPIEndpoint;
